@@ -185,10 +185,10 @@ class ScriptNamingTest(TestBase):
             script._rev_path(
                 script.versions, "12345", "this is a message", create_date
             ),
-            os.path.abspath(
+            Path(
                 "%s/versions/12345_this_is_a_"
                 "message_2012_7_25_15_8_5.py" % _get_staging_directory()
-            ),
+            ).absolute(),
         )
 
     @testing.combinations(
@@ -219,7 +219,7 @@ class ScriptNamingTest(TestBase):
             script._rev_path(
                 script.versions, "12345", "this is a message", create_date
             ),
-            os.path.abspath(expected % _get_staging_directory()),
+            Path(expected % _get_staging_directory()).absolute(),
         )
 
     def _test_tz(self, timezone_arg, given, expected):
@@ -235,7 +235,13 @@ class ScriptNamingTest(TestBase):
         with mock.patch(
             "alembic.script.base.datetime",
             mock.Mock(
-                datetime=mock.Mock(utcnow=lambda: given, now=lambda: given),
+                datetime=mock.Mock(
+                    now=lambda tz=None: (
+                        given.replace(tzinfo=datetime.timezone.utc)
+                        if timezone_arg
+                        else given
+                    )
+                ),
                 timezone=datetime.timezone,
             ),
         ):
@@ -276,6 +282,19 @@ class ScriptNamingTest(TestBase):
             ),
         )
 
+    def test_generates_a_date(self):
+        """test #1643"""
+        script = ScriptDirectory(
+            _get_staging_directory(),
+            file_template="%(rev)s_%(slug)s_"
+            "%(year)s_%(month)s_"
+            "%(day)s_%(hour)s_"
+            "%(minute)s_%(second)s",
+            timezone="utc",
+        )
+        # generates a date with no warnings
+        eq_(script._generate_create_date(), mock.ANY)
+
     def test_default_tz(self):
         self._test_tz(
             None,
@@ -297,7 +316,7 @@ class ScriptNamingTest(TestBase):
         with patch("alembic.script.base.ZoneInfo", new=None):
             with expect_raises_message(
                 CommandError,
-                "Python >= 3.9 is required for timezone support or"
+                "Python >= 3.9 is required for timezone support or "
                 "the 'backports.zoneinfo' package must be installed.",
             ):
                 self._test_tz(
@@ -657,8 +676,9 @@ def downgrade():
             result = handle.read()
         assert (
             (
-                """
+                '''
 def upgrade() -> None:
+    """Upgrade schema."""
     # ### commands auto generated by Alembic - please adjust! ###
     op.create_table('test_table',
     sa.Column('id', sa.Integer(), nullable=False),
@@ -666,7 +686,7 @@ def upgrade() -> None:
     sa.PrimaryKeyConstraint('id')
     )
     # ### end Alembic commands ###
-"""
+'''
             )
             in result
         )
@@ -933,6 +953,11 @@ class RewriterTest(TestBase):
             idx_op = ops.CreateIndexOp("ixt", op.table_name, [op.column.name])
             return [op, idx_op]
 
+        def process_revision_directives(context, revision, generate_revisions):
+            generate_revisions[0].downgrade_ops = ops.DowngradeOps(
+                ops=[ops.DropColumnOp("t1", "x")]
+            )
+
         directives = [
             ops.MigrationScript(
                 util.rev_id(),
@@ -956,7 +981,8 @@ class RewriterTest(TestBase):
         ]
 
         ctx, rev = mock.Mock(), mock.Mock()
-        writer1.chain(writer2)(ctx, rev, directives)
+        writer = writer1.chain(process_revision_directives).chain(writer2)
+        writer(ctx, rev, directives)
 
         eq_(
             autogenerate.render_python_code(directives[0].upgrade_ops),
@@ -970,6 +996,13 @@ class RewriterTest(TestBase):
             "    # ### end Alembic commands ###",
         )
 
+        eq_(
+            autogenerate.render_python_code(directives[0].downgrade_ops),
+            "# ### commands auto generated by Alembic - please adjust! ###\n"
+            "    op.drop_column('t1', 'x')\n"
+            "    # ### end Alembic commands ###",
+        )
+
     def test_no_needless_pass(self):
         writer1 = autogenerate.Rewriter()
 
@@ -1167,7 +1200,8 @@ class MultiDirRevisionCommandTest(TestBase):
     def test_multiple_dir_no_bases_invalid_version_path(self):
         assert_raises_message(
             util.CommandError,
-            "Path foo/bar/ is not represented in current version locations",
+            r"Path foo[/\\]bar is not represented in current version "
+            "locations",
             command.revision,
             self.cfg,
             message="x",
@@ -1363,49 +1397,27 @@ class NormPathTest(TestBase):
 
         script = ScriptDirectory.from_config(config)
 
-        def normpath(path):
-            return path.replace("/", ":NORM:")
+        eq_(
+            script._version_locations,
+            [Path(_get_staging_directory(), "scripts", "versions").absolute()],
+        )
 
-        normpath = mock.Mock(side_effect=normpath)
-
-        with mock.patch("os.path.normpath", normpath):
-            eq_(
-                script._version_locations,
-                (
-                    os.path.abspath(
-                        os.path.join(
-                            _get_staging_directory(), "scripts", "versions"
-                        )
-                    ).replace("/", ":NORM:"),
-                ),
-            )
-
-            eq_(
-                script.versions,
-                os.path.abspath(
-                    os.path.join(
-                        _get_staging_directory(), "scripts", "versions"
-                    )
-                ).replace("/", ":NORM:"),
-            )
+        eq_(
+            Path(script.versions),
+            Path(_get_staging_directory(), "scripts", "versions").absolute(),
+        )
 
     def test_script_location_multiple(self):
         config = _multi_dir_testing_config()
 
         script = ScriptDirectory.from_config(config)
 
-        def _normpath(path):
-            return path.replace("/", ":NORM:")
-
-        normpath = mock.Mock(side_effect=_normpath)
-
-        with mock.patch("os.path.normpath", normpath):
-            sd = Path(_get_staging_directory()).as_posix()
-            eq_(
-                script._version_locations,
-                [
-                    _normpath(os.path.abspath(sd + "/model1/")),
-                    _normpath(os.path.abspath(sd + "/model2/")),
-                    _normpath(os.path.abspath(sd + "/model3/")),
-                ],
-            )
+        sd = Path(_get_staging_directory()).as_posix()
+        eq_(
+            script._version_locations,
+            [
+                Path(sd, "model1").absolute(),
+                Path(sd, "model2").absolute(),
+                Path(sd, "model3").absolute(),
+            ],
+        )
